Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(144)

Unified Diff: components/autofill/core/browser/autofill_client.h

Issue 2789843004: [Payments] Upload card UI now has a CVC prompt (Closed)
Patch Set: Addressing code review comments Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/core/browser/autofill_client.h
diff --git a/components/autofill/core/browser/autofill_client.h b/components/autofill/core/browser/autofill_client.h
index a10c3b302684c78690546db6f8b465235c3e553b..c0d278db362c5c159b0fd94e03dc8ab8b924167a 100644
--- a/components/autofill/core/browser/autofill_client.h
+++ b/components/autofill/core/browser/autofill_client.h
@@ -18,6 +18,10 @@
#include "ui/base/window_open_disposition.h"
#include "url/gurl.h"
+#if !defined(OS_ANDROID)
+#include "components/autofill/core/browser/ui/save_card_bubble_controller.h"
Evan Stade 2017/04/10 21:53:16 I suspect you can get by with a forward declaratio
Jared Saul 2017/04/11 22:57:47 Done.
+#endif
+
class IdentityProvider;
class PrefService;
@@ -110,9 +114,15 @@ class AutofillClient : public RiskDataLoader {
// Gets the RapporServiceImpl associated with the client (for metrics).
virtual rappor::RapporServiceImpl* GetRapporServiceImpl() = 0;
- // Gets the UKM service assiciated with this client (for metrics).
+ // Gets the UKM service associated with this client (for metrics).
virtual ukm::UkmService* GetUkmService() = 0;
+#if !defined(OS_ANDROID)
Evan Stade 2017/04/10 21:53:16 it would be great if you could avoid these ifdefs
Jared Saul 2017/04/11 22:57:47 Done.
+ // Gets the SaveCardBubbleController instance associated with the client.
+ // May return nullptr if the save card bubble has not been shown yet.
+ virtual SaveCardBubbleController* GetSaveCardBubbleController() = 0;
+#endif
+
// Causes the Autofill settings UI to be shown.
virtual void ShowAutofillSettings() = 0;
@@ -129,10 +139,12 @@ class AutofillClient : public RiskDataLoader {
const base::Closure& callback) = 0;
// Runs |callback| if the |card| should be uploaded to Payments. Displays the
// contents of |legal_message| to the user.
virtual void ConfirmSaveCreditCardToCloud(
const CreditCard& card,
std::unique_ptr<base::DictionaryValue> legal_message,
+ bool should_cvc_be_requested,
const base::Closure& callback) = 0;
// Will show an infobar to get user consent for Credit Card assistive filling.
@@ -129,10 +139,12 @@ class AutofillClient : public RiskDataLoader {
const base::Closure& callback) = 0;
// Runs |callback| if the |card| should be uploaded to Payments. Displays the
- // contents of |legal_message| to the user.
+ // contents of |legal_message| to the user. Display a CVC field in the bubble
+ // if |should_cvc_be_requested| is true.
virtual void ConfirmSaveCreditCardToCloud(
const CreditCard& card,

Powered by Google App Engine
This is Rietveld 408576698